<?php

namespace UnicaenCode\Form;

use UnicaenCode\Util;
use Zend\Form\Element;

abstract class AbstractForm extends \Zend\Form\Form
{

    public function addText($name, $label, $value = null): self
    {
        $options = [
            'type'    => 'Text',
            'name'    => $name,
            'options' => [
                'label' => $label,
            ],
        ];

        if ($value !== null) {
            $options['attributes']['value'] = $value;
        }

        $this->add($options);

        return $this;
    }



    public function addHidden(string $name, ?string $value = null): self
    {
        $options = [
            'type'       => 'Hidden',
            'name'       => $name,
            'attributes' => ['value' => $value],
        ];
        $this->add($options);

        return $this;
    }



    public function addCheckbox($name, $label, $value = false): self
    {
        $options = [
            'type'    => 'Checkbox',
            'name'    => $name,
            'options' => [
                'label' => $label,
            ],
        ];

        if ($value !== null) {
            $options['attributes']['value'] = $value;
        }

        $this->add($options);

        return $this;
    }



    public function addSubmit($name, $value): self
    {
        $options = [
            'type'       => 'Submit',
            'name'       => $name,
            'attributes' => [
                'value' => $value,
                'class' => 'btn btn-primary',
            ],
        ];

        $this->add($options);

        return $this;
    }



    public function addSelect($name, $label, $options, $value): self
    {
        $select = new Element\Select($name);
        $select->setLabel($label);
        $select->setValueOptions($options);
        $select->setValue($value);

        $this->add($select);

        return $this;
    }



    public function addSelectModule($name, $label, $value = 'Application'): self
    {
        $options = [
            'module' => [
                'label'   => 'Module',
                'options' => [],
            ],
            'vendor' => [
                'label'   => 'Vendor',
                'options' => [],
            ],
        ];
        $modules = Util::introspection()->getModules(true);
        ksort($modules);
        foreach ($modules as $mName => $module) {
            if ($module['inVendor']) {
                $options['vendor']['options'][$mName] = $mName;
            } else {
                $options['module']['options'][$mName] = $mName;
            }
        }

        return $this->addSelect($name, $label, $options, $value);
    }



    public function addSelectEntity(string $name, string $label, ?string $namespace = null, $value = null): self
    {
        $options  = [];
        $entities = Util::introspection()->getDbEntities($namespace);

        ksort($entities);
        foreach ($entities as $entity) {
            if ($namespace && 0 === strpos($entity, $namespace)) {
                $entity = substr($entity, strlen($namespace) + 1);
            }
            $options[$entity] = $entity;
        }

        return $this->addSelect($name, $label, $options, $value);
    }



    public function getParams(): array
    {
        return [];
    }
}