<?php

namespace UnicaenCode\Generator;

use UnicaenCode\Util;

class Controller implements GeneratorInterface
{
    /**
     * @param array $params
     *
     * Paramètres en entrée :
     *
     * - class => string nom de la classe pour laquelle le AwareTrait sera généré
     *
     * @return array
     */
    public function generate(array $params): array
    {
        $class    = $params['class'] ?? null;
        $type     = $params['type'] ?? Util::classType($class) ?? 'Controller';
        $author   = $params['author'] ?? Util::getAuthor();
        $template = $params['template'] ?? 'Controller';

        $namespace = Util::classNamespace($class);
        $classname = Util::classClassname($class);
        $filename  = Util::classFilename($class);

        $params['namespace'] = $namespace;
        $params['classname'] = $classname;
        $params['author']    = $author;
        $params['template']  = $template;
        $params['type']      = $type;
        $params['filename']  = $filename;

        return $params;
    }



    public function generateFactory(array &$params)
    {
        $p = &$params['factory'];

        $p['generator'] = $p['generator'] ?? 'Factory';
        $p['class']     = $params['class'];
        if (isset($params['type'])) $p['type'] = $params['type'];
        if (isset($params['author'])) $p['author'] = $params['author'];
        $p['echo']  = $p['echo'] ?? $params['echo'] ?? $params['echo'] ?? false;
        $p['write'] = $p['write'] ?? $params['write'] ?? false;

        $params['factory'] = Util::codeGenerator()->generate($p);
    }



    protected function generateConfig(array &$params)
    {
        $pc = &$params['config'];

        $p['generator'] = $p['generator'] ?? 'ControllerConfig';
        $p['class']     = $params['class'];
        $p['type']      = $params['type'];
        $p['author']    = $params['author'];
        $p['subDir']    = $params['factory']['subDir'] ?? true;
        $p['echo']      = $params['echo'] ?? $params['echo'] ?? false;

        $params['config'] = Util::codeGenerator()->generate($p);
    }



    public function generateFromParent(array $parentParams, array $params): array
    {
        return $params;
    }

}