<?php

namespace UnicaenCode\Generator;

use UnicaenCode\Util;

class Factory implements GeneratorInterface
{
    /**
     * @param array $params
     *
     * Paramètres en entrée :
     *
     * - classname => string nom de la classe pour laquelle le AwareTrait sera généré
     * - subDir => boolean true si on place le trait dans un sous-dossier Traits
     *
     * @return array
     */
    public function generate(array $params): array
    {
        $class    = $params['class'] ?? null;
        $template = $params['template'] ?? 'Factory';
        $subDir   = (bool)($params['subDir'] ?? true);
        $type     = $params['type'] ?? Util::classType($class);
        $author   = $params['author'] ?? Util::getAuthor();


        $namespace       = Util::classNamespace($class) . ($subDir ? '\\Factory' : '');
        $targetClass     = $class;
        $targetClassname = Util::classClassname($targetClass);
        $classname       = $targetClassname . 'Factory';
        $variable        = lcfirst($type ?: lcfirst($targetClass));
        $filename        = Util::classFilename($namespace.'\\'.$classname);
        $controllerForm  = in_array($type, ['Form', 'Fieldset', 'Controller']);


        $params['namespace']       = $namespace;
        $params['subDir']          = $subDir;
        $params['targetClass']     = $targetClass;
        $params['classname']       = $classname;
        $params['author']          = $author;
        $params['targetClassname'] = $targetClassname;
        $params['controllerForm']  = $controllerForm;
        $params['variable']        = $variable;
        $params['filename']        = $filename;
        $params['template']        = $template;

        return $params;
    }



    public function generateFromParent(array $parentParams, array $params): array
    {
        $useParams = ['class', 'type', 'author','subDir'];
        foreach ($useParams as $useParam) {
            if (isset($parentParams[$useParam])) $params[$useParam] = $parentParams[$useParam];
        }

        return $params;
    }

}